package client

import (
	"net/http"
	"random.chars.jp/git/image-board/api"
	"random.chars.jp/git/image-board/store"
	"strconv"
)

// Tags returns a slice of tag names on Remote.
func (r *Remote) Tags() ([]string, error) {
	var tags []string
	err := r.fetch(http.MethodGet, api.Tag, &tags, nil)
	return tags, err
}

// Tag returns a slice of snowflakes in a given tag.
func (r *Remote) Tag(tag string) ([]string, error) {
	var flakes []string
	err := r.fetch(http.MethodGet, populateField(api.TagField, "tag", tag), &flakes, nil)
	return flakes, err
}

// TagPage returns a slice of snowflakes in a page of a given tag.
func (r *Remote) TagPage(tag string, entry int) ([]string, error) {
	var flakes []string
	err := r.fetch(http.MethodGet,
		populateField(populateField(api.TagPageField,
			"tag", tag),
			"entry", strconv.Itoa(entry)),
		&flakes, nil)
	return flakes, err
}

// TagPageImages returns a slice of store.Image in a page of a given tag.
func (r *Remote) TagPageImages(tag string, entry int) ([]store.Image, error) {
	var images []store.Image
	err := r.fetch(http.MethodGet,
		populateField(populateField(api.TagPageImage,
			"tag", tag),
			"entry", strconv.Itoa(entry)),
		&images, nil)
	return images, err
}

// TagPages returns total amount of pages of a tag.
func (r *Remote) TagPages(tag string) (int, error) {
	if payload, err := r.fetchAll(http.MethodGet,
		populateField(api.TagPage, "tag", tag), nil); err != nil {
		return 0, err
	} else {
		var pages int
		if pages, err = strconv.Atoi(string(payload)); err != nil {
			return 0, err
		} else {
			return pages, nil
		}
	}
}

// TagCreate creates a tag on Remote.
func (r *Remote) TagCreate(tag string) error {
	return r.requestNoResp(http.MethodPut, populateField(api.TagField, "tag", tag), nil)
}

// TagDestroy destroys a tag on Remote.
func (r *Remote) TagDestroy(tag string) error {
	return r.requestNoResp(http.MethodDelete, populateField(api.TagField, "tag", tag), nil)
}

// TagInfo returns store.Tag of given tag.
func (r *Remote) TagInfo(tag string) (store.Tag, error) {
	var t store.Tag
	err := r.fetch(http.MethodGet, populateField(api.TagInfo, "tag", tag), &t, nil)
	return t, err
}

// TagType sets type of given tag.
func (r *Remote) TagType(tag, t string) error {
	return r.requestJSONnoResp(http.MethodPatch, populateField(api.TagInfo, "tag", tag), api.TagUpdatePayload{Type: t})
}
