package store

import (
	"errors"
	"regexp"
)

const letters = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ"

const (
	// Artist is the tag type artist.
	Artist = "artist"
	// Character is the tag type character.
	Character = "character"
	// Copyright is the tag type copyright.
	Copyright = "copyright"
	// Generic is the tag type generic.
	Generic = "generic"
	// Group is the tag type group.
	Group = "group"
	// Meta is the tag type meta.
	Meta = "meta"
)

var (
	nameRegex   = regexp.MustCompile(`^[a-z0-9()_-]{3,}$`)
	sha256Regex = regexp.MustCompile(`\b[A-Fa-f0-9]{64}\b`)
	secretRegex = regexp.MustCompile(`\b[A-Za-z]{64}\b`)
	urlRegex    = regexp.MustCompile(`(\b(https?|ftp)://)?[-A-Za-z0-9+&@#/%?=~_|!:,.;]+[-A-Za-z0-9+&@#/%=~_|]`)
)

var (
	// AlreadyExists is returned when store already exists.
	AlreadyExists = errors.New("store path already exists")
)

func (s *Store) MatchName(subject string) bool {
	return nameRegex.MatchString(subject)
}
